# coding: utf-8

"""
    PirlPay API

    The PirlPay API for automated payment processing  # noqa: E501

    OpenAPI spec version: v1
    Contact: support@pirl.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class BillingPlan(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'description': 'str',
        'frequency': 'int',
        'activated': 'bool',
        'price': 'float',
        'currency': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'frequency': 'frequency',
        'activated': 'activated',
        'price': 'price',
        'currency': 'currency'
    }

    def __init__(self, id=None, name=None, description=None, frequency=None, activated=None, price=None, currency=None):  # noqa: E501
        """BillingPlan - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._description = None
        self._frequency = None
        self._activated = None
        self._price = None
        self._currency = None
        self.discriminator = None
        if id is not None:
            self.id = id
        self.name = name
        self.description = description
        if frequency is not None:
            self.frequency = frequency
        if activated is not None:
            self.activated = activated
        self.price = price
        if currency is not None:
            self.currency = currency

    @property
    def id(self):
        """Gets the id of this BillingPlan.  # noqa: E501


        :return: The id of this BillingPlan.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BillingPlan.


        :param id: The id of this BillingPlan.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this BillingPlan.  # noqa: E501


        :return: The name of this BillingPlan.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BillingPlan.


        :param name: The name of this BillingPlan.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this BillingPlan.  # noqa: E501


        :return: The description of this BillingPlan.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BillingPlan.


        :param description: The description of this BillingPlan.  # noqa: E501
        :type: str
        """
        if description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def frequency(self):
        """Gets the frequency of this BillingPlan.  # noqa: E501

        1 DAY -- 2 WEEK -- 3 MONTH - 4 YEAR  # noqa: E501

        :return: The frequency of this BillingPlan.  # noqa: E501
        :rtype: int
        """
        return self._frequency

    @frequency.setter
    def frequency(self, frequency):
        """Sets the frequency of this BillingPlan.

        1 DAY -- 2 WEEK -- 3 MONTH - 4 YEAR  # noqa: E501

        :param frequency: The frequency of this BillingPlan.  # noqa: E501
        :type: int
        """

        self._frequency = frequency

    @property
    def activated(self):
        """Gets the activated of this BillingPlan.  # noqa: E501


        :return: The activated of this BillingPlan.  # noqa: E501
        :rtype: bool
        """
        return self._activated

    @activated.setter
    def activated(self, activated):
        """Sets the activated of this BillingPlan.


        :param activated: The activated of this BillingPlan.  # noqa: E501
        :type: bool
        """

        self._activated = activated

    @property
    def price(self):
        """Gets the price of this BillingPlan.  # noqa: E501


        :return: The price of this BillingPlan.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this BillingPlan.


        :param price: The price of this BillingPlan.  # noqa: E501
        :type: float
        """
        if price is None:
            raise ValueError("Invalid value for `price`, must not be `None`")  # noqa: E501

        self._price = price

    @property
    def currency(self):
        """Gets the currency of this BillingPlan.  # noqa: E501

        0 USD -- 1 EUR -- 2 MUR  # noqa: E501

        :return: The currency of this BillingPlan.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this BillingPlan.

        0 USD -- 1 EUR -- 2 MUR  # noqa: E501

        :param currency: The currency of this BillingPlan.  # noqa: E501
        :type: str
        """
        allowed_values = ["0", "1", "2"]  # noqa: E501
        if currency not in allowed_values:
            raise ValueError(
                "Invalid value for `currency` ({0}), must be one of {1}"  # noqa: E501
                .format(currency, allowed_values)
            )

        self._currency = currency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BillingPlan, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BillingPlan):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    PirlPay API

    The PirlPay API for automated payment processing  # noqa: E501

    OpenAPI spec version: v1
    Contact: support@pirl.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ProductTransaction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'product': 'str',
        'quantity': 'int',
        'unit_price': 'float'
    }

    attribute_map = {
        'id': 'id',
        'product': 'product',
        'quantity': 'quantity',
        'unit_price': 'unit_price'
    }

    def __init__(self, id=None, product=None, quantity=None, unit_price=None):  # noqa: E501
        """ProductTransaction - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._product = None
        self._quantity = None
        self._unit_price = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if product is not None:
            self.product = product
        self.quantity = quantity
        self.unit_price = unit_price

    @property
    def id(self):
        """Gets the id of this ProductTransaction.  # noqa: E501


        :return: The id of this ProductTransaction.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProductTransaction.


        :param id: The id of this ProductTransaction.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def product(self):
        """Gets the product of this ProductTransaction.  # noqa: E501

        the product that were billed  # noqa: E501

        :return: The product of this ProductTransaction.  # noqa: E501
        :rtype: str
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this ProductTransaction.

        the product that were billed  # noqa: E501

        :param product: The product of this ProductTransaction.  # noqa: E501
        :type: str
        """

        self._product = product

    @property
    def quantity(self):
        """Gets the quantity of this ProductTransaction.  # noqa: E501


        :return: The quantity of this ProductTransaction.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this ProductTransaction.


        :param quantity: The quantity of this ProductTransaction.  # noqa: E501
        :type: int
        """
        if quantity is None:
            raise ValueError("Invalid value for `quantity`, must not be `None`")  # noqa: E501

        self._quantity = quantity

    @property
    def unit_price(self):
        """Gets the unit_price of this ProductTransaction.  # noqa: E501

        the unit price in FIAT for the product  # noqa: E501

        :return: The unit_price of this ProductTransaction.  # noqa: E501
        :rtype: float
        """
        return self._unit_price

    @unit_price.setter
    def unit_price(self, unit_price):
        """Sets the unit_price of this ProductTransaction.

        the unit price in FIAT for the product  # noqa: E501

        :param unit_price: The unit_price of this ProductTransaction.  # noqa: E501
        :type: float
        """
        if unit_price is None:
            raise ValueError("Invalid value for `unit_price`, must not be `None`")  # noqa: E501

        self._unit_price = unit_price

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProductTransaction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProductTransaction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    PirlPay API

    The PirlPay API for automated payment processing  # noqa: E501

    OpenAPI spec version: v1
    Contact: support@pirl.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from pirlpay.pirlpay.billing_api import BillingApi
from pirlpay.pirlpay.catalogs_api import CatalogsApi
from pirlpay.pirlpay.payments_api import PaymentsApi
# import ApiClient
from pirlpay.api_client import ApiClient
from pirlpay.configuration import Configuration
# import models into sdk package
from pirlpay.pirlpay.billing_plan import BillingPlan
from pirlpay.pirlpay.product import Product
from pirlpay.pirlpay.product_transaction import ProductTransaction
from pirlpay.pirlpay.simple_payment import SimplePayment
from pirlpay.pirlpay.simple_payment_get import SimplePaymentGet
from pirlpay.pirlpay.subscription import Subscription
from pirlpay.pirlpay.subscription_transaction import SubscriptionTransaction



# coding: utf-8

"""
    PirlPay API

    The PirlPay API for automated payment processing  # noqa: E501

    OpenAPI spec version: v1
    Contact: support@pirl.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pirlpay
from pirlpay.subscription_transaction import SubscriptionTransaction  # noqa: E501
from pirlpay.rest import ApiException


class TestSubscriptionTransaction(unittest.TestCase):
    """SubscriptionTransaction unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSubscriptionTransaction(self):
        """Test SubscriptionTransaction"""
        # FIXME: construct object with mandatory attributes with example values
        # model = pirlpay.models.subscription_transaction.SubscriptionTransaction()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    PirlPay API

    The PirlPay API for automated payment processing  # noqa: E501

    OpenAPI spec version: v1
    Contact: support@pirl.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Subscription(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'date_billing_end': 'datetime',
        'active': 'bool',
        'cancelled': 'bool',
        'suspend': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'date_billing_end': 'date_billing_end',
        'active': 'active',
        'cancelled': 'cancelled',
        'suspend': 'suspend'
    }

    def __init__(self, id=None, date_billing_end=None, active=None, cancelled=None, suspend=None):  # noqa: E501
        """Subscription - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._date_billing_end = None
        self._active = None
        self._cancelled = None
        self._suspend = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if date_billing_end is not None:
            self.date_billing_end = date_billing_end
        if active is not None:
            self.active = active
        if cancelled is not None:
            self.cancelled = cancelled
        if suspend is not None:
            self.suspend = suspend

    @property
    def id(self):
        """Gets the id of this Subscription.  # noqa: E501


        :return: The id of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Subscription.


        :param id: The id of this Subscription.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def date_billing_end(self):
        """Gets the date_billing_end of this Subscription.  # noqa: E501

        the date to finish billing this subscription  # noqa: E501

        :return: The date_billing_end of this Subscription.  # noqa: E501
        :rtype: datetime
        """
        return self._date_billing_end

    @date_billing_end.setter
    def date_billing_end(self, date_billing_end):
        """Sets the date_billing_end of this Subscription.

        the date to finish billing this subscription  # noqa: E501

        :param date_billing_end: The date_billing_end of this Subscription.  # noqa: E501
        :type: datetime
        """

        self._date_billing_end = date_billing_end

    @property
    def active(self):
        """Gets the active of this Subscription.  # noqa: E501

        whether this subscription is active or not  # noqa: E501

        :return: The active of this Subscription.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this Subscription.

        whether this subscription is active or not  # noqa: E501

        :param active: The active of this Subscription.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def cancelled(self):
        """Gets the cancelled of this Subscription.  # noqa: E501

        whether this subscription is cancelled or not  # noqa: E501

        :return: The cancelled of this Subscription.  # noqa: E501
        :rtype: bool
        """
        return self._cancelled

    @cancelled.setter
    def cancelled(self, cancelled):
        """Sets the cancelled of this Subscription.

        whether this subscription is cancelled or not  # noqa: E501

        :param cancelled: The cancelled of this Subscription.  # noqa: E501
        :type: bool
        """

        self._cancelled = cancelled

    @property
    def suspend(self):
        """Gets the suspend of this Subscription.  # noqa: E501

        whether this subscription is suspended or not  # noqa: E501

        :return: The suspend of this Subscription.  # noqa: E501
        :rtype: bool
        """
        return self._suspend

    @suspend.setter
    def suspend(self, suspend):
        """Sets the suspend of this Subscription.

        whether this subscription is suspended or not  # noqa: E501

        :param suspend: The suspend of this Subscription.  # noqa: E501
        :type: bool
        """

        self._suspend = suspend

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Subscription, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Subscription):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    PirlPay API

    The PirlPay API for automated payment processing

    OpenAPI spec version: v1
    Contact: support@pirl.io
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "pirlpay"
VERSION = "0.0.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="PirlPay API",
    author_email="support@pirl.io",
    url="",
    keywords=["PirlPay API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    The PirlPay API for automated payment processing for https://pirlpay.com \n
    - API version: v1 \n
    - Package version: 0.0.1\n

    ## Requirements.\n

    Python 2.7 and 3.4+\n

    ## Installation & Usage\n
    pip install pirlpay \n

    """
)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from pirlpay.pirlpay.billing_api import BillingApi
from pirlpay.pirlpay.catalogs_api import CatalogsApi
from pirlpay.pirlpay.payments_api import PaymentsApi
